@@ -1,11 +1,11 @@
 package Net::DNS::SEC;
 
 #
-# $Id: SEC.pm 1673 2018-05-02 07:16:47Z willem $
+# $Id: SEC.pm 1702 2018-07-28 07:39:01Z willem $
 #
 our $VERSION;
-$VERSION = '1.07_02';
-our $SVNVERSION = (qw$LastChangedRevision: 1673 $)[1];
+$VERSION = '1.09_01';
+our $SVNVERSION = (qw$LastChangedRevision: 1702 $)[1];
 our $XS_VERSION = $VERSION;
 $VERSION = eval($VERSION);
 
@@ -20,17 +20,13 @@ Net::DNS::SEC - DNSSEC extensions to Net::DNS
 
 =head1 DESCRIPTION
 
-The Net::DNS::SEC suite provides additional packages required to support
-DNSSEC as described in RFC4033, RFC4034, RFC4035 and subsequent related
-documents.
-
-It also provides support for SIG0 which is useful for dynamic updates
-using key-pairs.
-
-RSA, DSA and elliptic curve crypto algorithms are supported.
-
 Net::DNS::SEC is installed as an extension to an existing Net::DNS
-installation.
+installation providing additional packages to support DNSSEC as
+described in RFC4033, RFC4034, RFC4035 and related documents.
+
+It also provides support for SIG0 which is useful for dynamic updates.
+
+RSA, DSA, ECDSA, and Edwards curve crypto algorithms are supported.
 
 The extended features are made available by replacing Net::DNS by
 Net::DNS::SEC in the use declaration.
@@ -50,15 +46,6 @@ use integer;
 use warnings;
 use Carp;
 
-eval{ Net::DNS::SEC->bootstrap($XS_VERSION) } || warn;
-
-
-require Net::DNS::RR::CDS;
-require Net::DNS::RR::DLV;
-require Net::DNS::RR::DS;
-require Net::DNS::RR::RRSIG;
-require Net::DNS::RR::SIG;
-
 
 =head1 UTILITY FUNCTIONS
 
@@ -121,6 +108,16 @@ sub key_difference {
 }
 
 
+########################################
+
+eval { Net::DNS::SEC->bootstrap($XS_VERSION) } || warn;
+
+
+foreach (qw(DS CDS DLV RRSIG)) {
+	new Net::DNS::RR( type => $_ );				# pre-load to access class methods
+}
+
+
 1;
 __END__
 
